@@ -6,10 +6,11 @@
 */
 #ifndef WINDOWEFFECTS_H
 #define WINDOWEFFECTS_H
-#include <KWindowSystem/private/kwindoweffects_p.h>
 #include <kwindowsystem_version.h>
+#include <private/kwindoweffects_p.h>
 
 #include <QHash>
+#include <QObject>
 
 namespace KWayland
 {
